@@ -282,26 +282,26 @@ def change_dimension(x, nred=-1, fixedlim=False):
     return _np.linspace(_np.min(x), _np.max(x), len(x)+nred)
 
 
-def bindata(x, y, yerr=None, nbins=20, xlim=None, perc=0, interp=False, 
+def bindata(x, y, yerr=None, nbins=20, xlim=None, interp=False, perc=0,
     weightx=True):
     """
-    Return the weighted binned data.
-
-    if ``perc > 0``, then it returns the percentile value of the interval.
-
-    if yerr is None:
-        yerr = _np.ones(shape=_np.shape(x))
+    Return the weighted binned data. It is assumed no errors for x values.
 
     `interp` linearly interpolates NaN values in `y` (no changes on `x` and 
     `yerr` arrays).
 
-    `weightx=True` returns the averaged `x` value inside the bin. `False` 
-    returns the regularly spaced `x` values.
+    if ``perc > 0``, then it returns the percentile value of the interval. In 
+    this case, the output xvals will be the ones from the closest y  
+    value within a given bin corresponding to that percentile.
 
-    INPUT: x, y, err - arrays with the same shape (they don't need to be
-    sorted); nbins=int, xlim=[xmin, xmax]
+    `weightx` only works if `perc=0`. `True` returns the simply averaged `x` 
+    value of a given bin interval (it is not based on y or yerr values); 
+    `False` returns the regularly spaced `x` bin values.
 
-    OUTPUT: xvals, yvals, new_yerr (arrays)
+    INPUT: x, y, yerr - arrays with the same shape (they don't need to be
+    sorted); nbins=int, xlim=[xmin, xmax]. 
+
+    OUTPUT: xvals, yvals, new_yerr [if `yerr!=None`]; (arrays)
     """
     x = _np.array(x)
     y = _np.array(y)
@@ -591,6 +591,34 @@ def cart_rot(x, y, z, ang_xy=0., ang_yz=0., ang_zx=0.):
 
 
 # Lists and strings manipulation
+def isnumber(val, contains=False):
+    """Return [True|False] if a string can be converted to a number (int,  
+    float or scientific notation).
+
+    `contains`: check if the string CONTAINS a valid number.
+    """
+    rule = r"-?[\d.]+(?:e-?\d+)?"
+    match = _re.findall(rule, val)
+    isn = False
+    if len(match) == 1:
+        isn = True
+        if not contains:
+            if match[0] != val:
+                isn = False
+    return isn
+
+
+def str2float(val):
+    """Returns a float converted from the string ``val``. 
+
+    If more than one float is identified, it returns ``None``"""
+    rule = r"-?[\d.]+(?:e-?\d+)?"
+    match = _re.findall(rule, val)
+    if len(match) != 1:
+        return None
+    return float(match[0])
+
+
 def closest_idx(arr, mtx):
     """ Return the closest index of `mtx` corresponding to the values of `arr`.
     """
@@ -602,7 +630,8 @@ def closest_idx(arr, mtx):
 
 
 def unic2ascii(string):
-    return _unicdata.normalize('NFKD', unicode(string)).encode('ascii', 
+    """ Converts unicode to ASCII """
+    return _unicdata.normalize('NFKD', string).encode('ascii', 
         'ignore')
 
 
